.. _install:

************
Installation
************

.. note::

    ``twobody`` depends on the presently unreleased version 3.0 of `astropy`,
    which you can install with ``pip install
    git+https://github.com/astropy/astropy@v3.0.x``.

With `pip`
==========

.. image:: http://img.shields.io/pypi/v/twobody.svg?style=flat
        :target: https://pypi.python.org/pypi/twobody/

To install the latest stable version using ``pip``, use::

    pip install twobody

To install the latest development version::

    pip install git+https://github.com/adrn/TwoBody


From source
===========

The latest development version can be cloned from
`GitHub <https://github.com/>`_ using ``git``::

   git clone git://github.com/adrn/TwoBody.git

To install the project (from the root of the source tree, e.g., inside
the cloned ``TwoBody`` directory)::

    python setup.py install
